* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=120;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
  TITLE; ODS TRACE OFF; ODS LISTING; ODS HTML; ODS GRAPHICS OFF;

********************************************************************************;
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION       *******;
*******      BEGIN HOFFMAN CHAPTER 2 DATA IMPORT AND MANIPULATION        *******;  
********************************************************************************;

* Define global variable for file location to be replaced in code below;
* \\Client\ precedes path in Virtual Desktop outside H drive;
%LET filesave= C:\Dropbox\22SP_PSQF6243\PSQF6243_Example4b;
* Location for SAS files for these models (uses macro variable filesave);
LIBNAME filesave "&filesave.";

* Import chapter 2 example data into work library as Example4b;
DATA work.Example4b; SET filesave.SAS_Chapter2;
* Center quantitative predictors near their means;
  age85 = age - 85;
  grip9 = grip - 9;
* Create 2 indicator-dummy-coded binary predictors for 3 dementia groups;
  demNF=.; demNC=.; * Create two new empty variables;
  IF demgroup=1 THEN DO; demNF=0; demNC=0; END; * Replace each for none group;
  IF demgroup=2 THEN DO; demNF=1; demNC=0; END; * Replace each for future group;
  IF demgroup=3 THEN DO; demNF=0; demNC=1; END; * Replace each for current group;
* Label new variables  note semi-colon is only at the end of ALL labels;
  LABEL   
  age85=     "age85: Age in Years (0=85)"
  grip9=     "grip9: Grip Strength in Pounds (0=9)"
  sexMW=     "sexMW: Sex (0=M, 1=W)"
  demNF=     "demNF: Dementia Contrast for None=0 vs Future=1"
  demNC=     "demNC: Dementia Contrast for None=0 vs Current=1"
  cognition= "cognition: Cognition Outcome"
  demgroup=  "demgroup: Dementia Group 1N 2F 3C";
* Select cases complete on all variables to be used;
  IF NMISS(cognition,age,grip,sexMW,demgroup)>0 THEN DELETE;
RUN;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\Example4b_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;

********************************************************************************;
*******    ANALYSES: DESCRIPTION, CORRELATION, GENERAL LINEAR MODELS     *******;
********************************************************************************;

TITLE "SAS Descriptive Statistics for Quantitative Variables";
PROC MEANS NONOBS NDEC=3 MEAN STDDEV VAR MIN MAX DATA=work.Example4b; 
     VAR cognition age grip sexMW; 
RUN; TITLE;

TITLE "SAS Descriptive Statistics for Categorical Variables"; 
PROC FREQ DATA=work.Example4b;
     TABLE sexMW demgroup;
RUN; TITLE;

TITLE "SAS Bivariate Correlations (btw, OUT saves corrs to dataset)";
PROC CORR NOSIMPLE DATA=work.Example4b OUT=work.Corrs;
     VAR cognition age grip sexMW; 
RUN; TITLE;

TITLE "SAS Empty Model Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = / SOLUTION ALPHA=.05 CLPARM SS3;
RUN; QUIT; TITLE;

TITLE "SAS Linear + Quadratic Age (0=85) Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = age85 age85*age85 / SOLUTION ALPHA=.05 CLPARM  EFFECTSIZE;
RUN; QUIT; TITLE;

TITLE "SAS Linear + Quadratic Grip (0=9) Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = grip9 grip9*grip9 / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
RUN; QUIT; TITLE;

TITLE "SAS 3-Category Dementia Group (Ref=None) Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = demNF demNC / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
     ESTIMATE "Cognition Mean: None"         intercept 1 demNF  0 demNC  0; * B0;
     ESTIMATE "Cognition Mean: Future"       intercept 1 demNF  1 demNC  0; * B0+B1;
     ESTIMATE "Cognition Mean: Current"      intercept 1 demNF  0 demNC  1; * B0+B2;
     ESTIMATE "Mean Diff: None vs. Future"               demNF  1 demNC  0; * B1;
     ESTIMATE "Mean Diff: None vs. Current"              demNF  0 demNC  1; * B2;
     ESTIMATE "Mean Diff: Future vs. Current"            demNF -1 demNC  1; * B2-B1;
     ODS OUTPUT Estimates=work.DemEstimates; * Save for computing effect sizes;
RUN; QUIT; TITLE;
* SAS code to compute effect sizes from stored ESTIMATE results;
DATA work.DemEstimates; SET work.DemEstimates;
* Cohen d is partial standardized mean difference; 
  PartialD=(2*tValue)/SQRT(547); * SQRT(number) = DF denominator;
* PartialR is partial correlation;
  PartialR = tvalue/(SQRT(tvalue**2 +547)); * +number = DF denominator;
RUN;
* Print estimates table with effect sizes added;
TITLE "Effect Sizes for 3-Category DemGroup";
PROC PRINT NOOBS DATA=work.DemEstimates; 
     VAR Parameter Estimate StdErr probt PartialD PartialR; 
RUN; TITLE;


TITLE "SAS Combined Model Predicting Cognition";
PROC GLM DATA=work.Example4b NAMELEN=100;
     MODEL cognition = age85 grip9 sexMW demNF demNC / SOLUTION ALPHA=.05 CLPARM SS3 EFFECTSIZE;
     CONTRAST "F-Test DFnum=5 for Model (demo)" age85 1, grip9 1, sexMW 1, demNF 1, demNC 1;
     CONTRAST "F-Test DFnum=2 for Demgroup"      demNF  1, demNC  1; * For overall demgroup;
     CONTRAST "F-Test DFnum=2 for Age and Sex"   age85  1, sexMW  1; * For demographic vars;
     ESTIMATE "Mean Diff: Future vs. Current"    demNF -1  demNC  1; * B5-B4;
     ODS OUTPUT ParameterEstimates=work.ModelEstimates Estimates=work.ReqEstimates; 
RUN; QUIT; TITLE; * Save for computing effect sizes;
* Compute Cohen d effect size and r effect sizes;
DATA work.FinalEstimates; LENGTH Parameter $50; 
  SET work.ModelEstimates work.ReqEstimates; 
* Cohen d is partial standardized mean difference; 
  PartialD=(2*tValue)/SQRT(544); * SQRT(number) = DF denominator;
* PartialR is partial correlation;
  PartialR = tvalue/(SQRT(tvalue**2 +544)); * +number = DF denominator;
RUN;
* Print solution and estimates combined table with effect sizes;
TITLE "Effect Sizes for Combined Model";
PROC PRINT NOOBS DATA=work.FinalEstimates; 
     VAR Parameter Estimate StdErr probt PartialD PartialR; 
RUN; TITLE;


* Close output;
ODS RTF CLOSE;

