// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

********************************************************************************
******                  BEGIN IMPORT FOR CHAPTER 2 DATA                  *******
********************************************************************************

// Defining global variable for file location to be replaced in code below
// \\Client\ precedes path in Virtual Desktop outside H drive
    cd "C:\Dropbox\22SP_PSQF6243\PSQF6243_Example4b"

// Import chapter 2 data in STATA format
   use "STATA_Chapter2.dta", clear // Has converted all variables to lower-case
   
// Center quantitative predictors near their means
   gen age85 = age - 85
   gen grip9 = grip - 9
// Create 2 indicator-dummy-coded binary predictors for 3 dementia groups
   gen demnf=.  // Create 2 new empty variables 
   gen demnc=.
// Replace for demgroup = none   
   replace demnf=0 if demgroup==1
   replace demnc=0 if demgroup==1
// Replace for demgroup = future 
   replace demnf=1 if demgroup==2
   replace demnc=0 if demgroup==2
// Replace for demgroup = current
   replace demnf=0 if demgroup==3
   replace demnc=1 if demgroup==3
// Label all variables
   label variable age85     "age85: Age in Years (0=85)"
   label variable grip9     "grip9: Grip Strength in Pounds (0=9)"
   label variable sexmw     "sexmw: Sex (0=Men, 1=Women)"
   label variable demnf     "demnf: Dementia Contrast for None=0 vs Future=1"
   label variable demnc     "demnc: Dementia Contrast for None=0 vs Current=1"
   label variable cognition "cognition: Cognition Outcome"
   label variable demgroup  "demgroup: Dementia Group 1N 2F 3C"
// Select cases complete on all variables to be used
   egen nmiss=rowmiss(cognition age grip sexmw demgroup)
   drop if nmiss>0

    
********************************************************************************
*******    ANALYSES: DESCRIPTION, CORRELATION, GENERAL LINEAR MODELS     *******
********************************************************************************

// Open external file to save results to
   log using Example4b_STATA_Output.log, replace

display "STATA Descriptive Statistics for Quantitative Predictors"
summarize cognition age grip sexmw, detail
display "STATA Descriptive Statistics for Categorical Predictors"
tabulate sexmw 
tabulate demgroup
       
display "STATA Bivariate Correlations"
pwcorr cognition age grip sexmw, sig 

display "STATA Empty Model Predicting Cognition"
regress cognition, level(95)

display "STATA Linear + Quadratic Age (0=85) Predicting Cognition"
regress cognition c.age85 c.age85#c.age85, level(95)

display "STATA Linear + Quadratic Grip (0=9) Predicting Cognition"
regress cognition c.grip9 c.grip9#c.grip9, level(95)

display "STATA Dementia Group (Ref=None) Predicting Cognition"
regress cognition c.demnf c.demnc, level(95)
lincom _cons*1 + c.demnf*0 + c.demnc*0 // Cognition Mean for None    = B0
lincom _cons*1 + c.demnf*1 + c.demnc*0 // Cognition Mean for Future  = B0+B1
lincom _cons*1 + c.demnf*0 + c.demnc*1 // Cognition Mean for Current = B0+B2
lincom c.demnf*1  + c.demnc*0 // Mean Diff: None vs. Future    = B1
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.demnf*0  + c.demnc*1 // Mean Diff: None vs. Current   = B2
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.demnf*-1 + c.demnc*1 // Mean Diff: Future vs. Current = B2-B1
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))

display "STATA Combined Model Predicting Cognition"
regress cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc, level(95)
test (c.age85=0)(c.grip9=0)(c.sexmw=0)(c.demnf=0)(c.demnc=0) // F-Test DFnum=5 for Model
test (c.demnf=0)(c.demnc=0)   // F-Test DFnum=2 for Demgroup (for overall demgroup)
test (c.age85=0)(c.sexmw=0)   // F-Test DFnum=2 for Age and Sex (for demographic vars)
lincom c.demnf*1  + c.demnc*0 // Mean Diff: None vs. Future    = B4
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.demnf*0  + c.demnc*1 // Mean Diff: None vs. Current   = B5
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
lincom c.demnf*-1 + c.demnc*1 // Mean Diff: Future vs. Current = B5-B4
   display "Partial D= "      (2*(r(estimate)/r(se)))/sqrt(r(df))
   display "Partial R= "      (r(estimate)/r(se))/sqrt((r(estimate)/r(se))^2+r(df))
// Get partial correlations for age, grip, and sex (sr2 for dem slopes are not valid)
pcorr cognition c.age85 c.grip9 c.sexmw c.demnf c.demnc 

// Stata: calculate semipartial eta-squared for demgroup using SS from reduced model
display "STATA Reduced Model to Get SS for demnf and demnc (as omitted)"
regress cognition c.age85 c.grip9 c.sexmw, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (18385.97930-6574.67775)/66296.5382 // sr2 for demgroup = .17815865

// Stata: calculate semipartial eta-squared for age and sex using SS from reduced model
display "STATA Reduced Model to Get SS for age85 and sexmw (as omitted)"
regress cognition c.grip9 c.demnf c.demnc, level(95)
// sr2 = (SSfull-SSreduced)/SStotal
display (18385.97930-15956.7691)/66296.5382 // sr2 for age and sex = .03664158


// Close external file of saved results
log close


